@@ -3,7 +3,7 @@
 # GNU General Public License, version 2 or later
 
 APPNAME = "Straw"
-VERSION = "0.24"
+VERSION = "0.25"
 STRAW_URL = "http://www.nongnu.org/straw/"
 STRAW_REF_URL = "%sstraw-ref.html" % STRAW_URL
 
@@ -18,9 +18,10 @@ FeedCategoriesChangedSignal, FeedDeletedSignal, FeedCreatedSignal, \
 FeedErrorStatusChangedSignal, PollFrequencyChangedSignal, \
 SubscriptionContentsUpdatedSignal, \
 FeedCategoryChangedSignal, FeedCategoryListChangedSignal, \
-FeedCategoryAddedSignal, FeedCategoryRemovedSignal, PollingStoppedSignal
+FeedCategoryAddedSignal, FeedCategoryRemovedSignal, PollingStoppedSignal, \
+FeedCategoryListLoadedSignal
 import Config
-from Feed import Feed, create_empty_feed, create_new_feed
+from Feed import Feed
 import FeedCategoryList
 from FeedDataRouter import FeedDataRouter
 import FeedList
@@ -29,7 +30,6 @@ from MainWindow import MainWindow, CategorySelector
 from PreferencesDialog import PreferencesDialog
 from QueueDict import FeedQD
 import SummaryParser
-from ItemStore import ItemStore
 from SummaryItem import SummaryItem
 from ParsedSummary import ParsedSummary
 import ImageCache
@@ -50,5 +50,6 @@ import DashboardFrontend
 from FeedItems import FeedItems
 import utils
 import MessageManager
-import Tray
+from Tray import Tray
 import ValueMonitor
+from MainloopManager import MainloopManager
